@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2005 IBM Corporation and others.
+ * Copyright (c) 2004, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,13 +14,12 @@
 package org.eclipse.core.tools;
 
 import org.eclipse.jface.action.Action;
-import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.viewers.TreeViewer;
 
 /**
  * @since 3.0
  */
-public class CollapseAllAction extends Action implements IAction {
+public class CollapseAllAction extends Action {
 
 	private static final String label = "Collapse All"; //$NON-NLS-1$
 	private static final String imageName = "collapseall.gif"; //$NON-NLS-1$
