@@ -26,6 +26,7 @@ import java.util.Iterator;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.Stack;
 import org.eclipse.e4.core.contexts.IContextFunction;
@@ -83,9 +84,7 @@ public class EclipseContext implements IEclipseContext {
 			if (getClass() != obj.getClass())
 				return false;
 			Scheduled other = (Scheduled) obj;
-			if (!event.equals(other.event))
-				return false;
-			return runnable.equals(other.runnable);
+			return Objects.equals(this.event, other.event) && Objects.equals(this.runnable, other.runnable);
 		}
 	}
 
@@ -133,7 +132,7 @@ public class EclipseContext implements IEclipseContext {
 	public Set<EclipseContext> getChildren() {
 		Set<EclipseContext> result;
 		synchronized (children) {
-			if (children.size() == 0)
+			if (children.isEmpty())
 				return noChildren;
 			result = new HashSet<>(children.size());
 			for (Iterator<WeakReference<EclipseContext>> i = children.iterator(); i.hasNext();) {
@@ -302,7 +301,7 @@ public class EclipseContext implements IEclipseContext {
 			computation.handleInvalid(event, scheduled);
 		}
 		Set<Computation> namedComputations = weakListeners.getListeners(name);
-		if (namedComputations != null && namedComputations.size() > 0) {
+		if (namedComputations != null && !namedComputations.isEmpty()) {
 			if (event == null) {
 				event = new ContextChangeEvent(this, eventType, null, name, oldValue);
 			}
@@ -405,7 +404,7 @@ public class EclipseContext implements IEclipseContext {
 		boolean containsKey = localValues.containsKey(name);
 		if (containsKey) {
 			if (!checkModifiable(name)) {
-				String tmp = "Variable " + name + " is not modifiable in the context " + toString(); //$NON-NLS-1$ //$NON-NLS-2$
+				String tmp = "Variable " + name + " is not modifiable in the context " + this; //$NON-NLS-1$ //$NON-NLS-2$
 				throw new IllegalArgumentException(tmp);
 			}
 			Object oldValue = localValues.put(name, value);
@@ -510,7 +509,7 @@ public class EclipseContext implements IEclipseContext {
 			if (localValues.containsKey(name))
 				continue; // it is a local value
 			Object oldValue = get(name);
-			Object newValue = (newParent != null) ? newParent.get(name) : null;
+			Object newValue = (newParent != null) ? newParent.internalGet(this, name, false) : null;
 			if (oldValue != newValue)
 				invalidate(name, ContextChangeEvent.ADDED, oldValue, newValue, scheduled);
 		}
